@@ -1,10 +1,10 @@
-__version__ = '0.0.23'  # print(ultralytics.__version__)
+__version__ = '0.0.24'  # print(ultralytics.__version__)
 
 
 def login():
     # Login to Ultralytics HUB
     from .main import connect_to_hub
-    connect_to_hub()
+    connect_to_hub(verbose=True)
 
 
 def start():
