@@ -18,11 +18,15 @@ def train_model() -> None:
         trainer.start()
 
 
-def connect_to_hub(password=False) -> bool:
+def connect_to_hub(password=False, verbose=False) -> bool:
     """Authenticates user with Ultralytics HUB"""
     global CONNECTED
-    if not CONNECTED:
+
+    if CONNECTED and verbose:
+        print(f'Already logged in.')
+    elif not CONNECTED:
         CONNECTED = AUTH.attempt_signin() if password else AUTH.attempt_api_key()
+
     return CONNECTED
 
 
