@@ -39,7 +39,7 @@ class Trainer:
                 print(f"{PREFIX}ERROR: Unable to fetch model")
                 return None  # Cannot train without model
             elif not res["data"]:
-                print(f"{PREFIX}No models pending training.")
+                print(f"{PREFIX}No models to train. Create YOLOv5 models to train at https://hub.ultralytics.com")
                 return None  # Cannot train without model
             else:
                 self.model_id = res["data"]["id"]  # Append id as it may be fetched from queue and unknown
